@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,17 +20,16 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.monitoring_dashboard_v1.services.dashboards_service import pagers
 from google.cloud.monitoring_dashboard_v1.types import dashboard
 from google.cloud.monitoring_dashboard_v1.types import dashboards_service
 from google.cloud.monitoring_dashboard_v1.types import layouts
-
 from .transports.base import DashboardsServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import DashboardsServiceGrpcAsyncIOTransport
 from .client import DashboardsServiceClient
@@ -50,42 +47,67 @@ class DashboardsServiceAsyncClient:
 
     dashboard_path = staticmethod(DashboardsServiceClient.dashboard_path)
     parse_dashboard_path = staticmethod(DashboardsServiceClient.parse_dashboard_path)
-
     common_billing_account_path = staticmethod(
         DashboardsServiceClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         DashboardsServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(DashboardsServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         DashboardsServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         DashboardsServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         DashboardsServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(DashboardsServiceClient.common_project_path)
     parse_common_project_path = staticmethod(
         DashboardsServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(DashboardsServiceClient.common_location_path)
     parse_common_location_path = staticmethod(
         DashboardsServiceClient.parse_common_location_path
     )
 
-    from_service_account_file = DashboardsServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            DashboardsServiceAsyncClient: The constructed client.
+        """
+        return DashboardsServiceClient.from_service_account_info.__func__(DashboardsServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            DashboardsServiceAsyncClient: The constructed client.
+        """
+        return DashboardsServiceClient.from_service_account_file.__func__(DashboardsServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> DashboardsServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             DashboardsServiceTransport: The transport used by the client instance.
@@ -99,12 +121,12 @@ class DashboardsServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, DashboardsServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the dashboards service client.
+        """Instantiates the dashboards service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -136,7 +158,6 @@ class DashboardsServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = DashboardsServiceClient(
             credentials=credentials,
             transport=transport,
@@ -152,16 +173,17 @@ class DashboardsServiceAsyncClient:
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dashboard.Dashboard:
-        r"""Creates a new custom dashboard.
-
+        r"""Creates a new custom dashboard. For examples on how you can use
+        this API to create dashboards, see `Managing dashboards by
+        API <https://cloud.google.com/monitoring/dashboards/api-dashboard>`__.
         This method requires the ``monitoring.dashboards.create``
-        permission on the specified project. For more information, see
-        `Google Cloud IAM <https://cloud.google.com/iam>`__.
+        permission on the specified project. For more information about
+        permissions, see `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Args:
-            request (:class:`~.dashboards_service.CreateDashboardRequest`):
+            request (:class:`google.cloud.monitoring_dashboard_v1.types.CreateDashboardRequest`):
                 The request object. The `CreateDashboard` request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -169,7 +191,7 @@ class DashboardsServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.dashboard.Dashboard:
+            google.cloud.monitoring_dashboard_v1.types.Dashboard:
                 A Google Stackdriver dashboard.
                 Dashboards define the content and layout
                 of pages in the Stackdriver web
@@ -177,7 +199,6 @@ class DashboardsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = dashboards_service.CreateDashboardRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -212,12 +233,12 @@ class DashboardsServiceAsyncClient:
 
         This method requires the ``monitoring.dashboards.list``
         permission on the specified project. For more information, see
-        `Google Cloud IAM <https://cloud.google.com/iam>`__.
+        `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Args:
-            request (:class:`~.dashboards_service.ListDashboardsRequest`):
+            request (:class:`google.cloud.monitoring_dashboard_v1.types.ListDashboardsRequest`):
                 The request object. The `ListDashboards` request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -225,15 +246,14 @@ class DashboardsServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListDashboardsAsyncPager:
-                The ``ListDashboards`` request.
+            google.cloud.monitoring_dashboard_v1.services.dashboards_service.pagers.ListDashboardsAsyncPager:
+                The ListDashboards request.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
 
         """
         # Create or coerce a protobuf request object.
-
         request = dashboards_service.ListDashboardsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -274,12 +294,12 @@ class DashboardsServiceAsyncClient:
 
         This method requires the ``monitoring.dashboards.get``
         permission on the specified dashboard. For more information, see
-        `Google Cloud IAM <https://cloud.google.com/iam>`__.
+        `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Args:
-            request (:class:`~.dashboards_service.GetDashboardRequest`):
+            request (:class:`google.cloud.monitoring_dashboard_v1.types.GetDashboardRequest`):
                 The request object. The `GetDashboard` request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -287,7 +307,7 @@ class DashboardsServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.dashboard.Dashboard:
+            google.cloud.monitoring_dashboard_v1.types.Dashboard:
                 A Google Stackdriver dashboard.
                 Dashboards define the content and layout
                 of pages in the Stackdriver web
@@ -295,7 +315,6 @@ class DashboardsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = dashboards_service.GetDashboardRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -330,12 +349,12 @@ class DashboardsServiceAsyncClient:
 
         This method requires the ``monitoring.dashboards.delete``
         permission on the specified dashboard. For more information, see
-        `Google Cloud IAM <https://cloud.google.com/iam>`__.
+        `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Args:
-            request (:class:`~.dashboards_service.DeleteDashboardRequest`):
+            request (:class:`google.cloud.monitoring_dashboard_v1.types.DeleteDashboardRequest`):
                 The request object. The `DeleteDashboard` request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -343,7 +362,6 @@ class DashboardsServiceAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-
         request = dashboards_service.DeleteDashboardRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -377,12 +395,12 @@ class DashboardsServiceAsyncClient:
 
         This method requires the ``monitoring.dashboards.update``
         permission on the specified dashboard. For more information, see
-        `Google Cloud IAM <https://cloud.google.com/iam>`__.
+        `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Args:
-            request (:class:`~.dashboards_service.UpdateDashboardRequest`):
+            request (:class:`google.cloud.monitoring_dashboard_v1.types.UpdateDashboardRequest`):
                 The request object. The `UpdateDashboard` request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -390,7 +408,7 @@ class DashboardsServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.dashboard.Dashboard:
+            google.cloud.monitoring_dashboard_v1.types.Dashboard:
                 A Google Stackdriver dashboard.
                 Dashboards define the content and layout
                 of pages in the Stackdriver web
@@ -398,7 +416,6 @@ class DashboardsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = dashboards_service.UpdateDashboardRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
