@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -36,7 +34,6 @@ from google.cloud.monitoring_dashboard_v1.services.dashboards_service import pag
 from google.cloud.monitoring_dashboard_v1.types import dashboard
 from google.cloud.monitoring_dashboard_v1.types import dashboards_service
 from google.cloud.monitoring_dashboard_v1.types import layouts
-
 from .transports.base import DashboardsServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import DashboardsServiceGrpcTransport
 from .transports.grpc_asyncio import DashboardsServiceGrpcAsyncIOTransport
@@ -59,7 +56,7 @@ class DashboardsServiceClientMeta(type):
     def get_transport_class(
         cls, label: str = None,
     ) -> Type[DashboardsServiceTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -84,7 +81,8 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -116,10 +114,27 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            DashboardsServiceClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -128,7 +143,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            DashboardsServiceClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -138,29 +153,30 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
     @property
     def transport(self) -> DashboardsServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            DashboardsServiceTransport: The transport used by the client instance.
+            DashboardsServiceTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def dashboard_path(project: str, dashboard: str,) -> str:
-        """Return a fully-qualified dashboard string."""
+        """Returns a fully-qualified dashboard string."""
         return "projects/{project}/dashboards/{dashboard}".format(
             project=project, dashboard=dashboard,
         )
 
     @staticmethod
     def parse_dashboard_path(path: str) -> Dict[str, str]:
-        """Parse a dashboard path into its component segments."""
+        """Parses a dashboard path into its component segments."""
         m = re.match(r"^projects/(?P<project>.+?)/dashboards/(?P<dashboard>.+?)$", path)
         return m.groupdict() if m else {}
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -173,7 +189,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -184,7 +200,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -195,7 +211,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -206,7 +222,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -220,12 +236,12 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, DashboardsServiceTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the dashboards service client.
+        """Instantiates the dashboards service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -233,10 +249,10 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.DashboardsServiceTransport]): The
+            transport (Union[str, DashboardsServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (client_options_lib.ClientOptions): Custom options for the
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -272,21 +288,18 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -298,12 +311,14 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -318,8 +333,8 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -329,7 +344,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -342,16 +357,17 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dashboard.Dashboard:
-        r"""Creates a new custom dashboard.
-
+        r"""Creates a new custom dashboard. For examples on how you can use
+        this API to create dashboards, see `Managing dashboards by
+        API <https://cloud.google.com/monitoring/dashboards/api-dashboard>`__.
         This method requires the ``monitoring.dashboards.create``
-        permission on the specified project. For more information, see
-        `Google Cloud IAM <https://cloud.google.com/iam>`__.
+        permission on the specified project. For more information about
+        permissions, see `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Args:
-            request (:class:`~.dashboards_service.CreateDashboardRequest`):
+            request (google.cloud.monitoring_dashboard_v1.types.CreateDashboardRequest):
                 The request object. The `CreateDashboard` request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -359,7 +375,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.dashboard.Dashboard:
+            google.cloud.monitoring_dashboard_v1.types.Dashboard:
                 A Google Stackdriver dashboard.
                 Dashboards define the content and layout
                 of pages in the Stackdriver web
@@ -367,7 +383,6 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a dashboards_service.CreateDashboardRequest.
         # There's no risk of modifying the input as we've already verified
@@ -403,12 +418,12 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
         This method requires the ``monitoring.dashboards.list``
         permission on the specified project. For more information, see
-        `Google Cloud IAM <https://cloud.google.com/iam>`__.
+        `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Args:
-            request (:class:`~.dashboards_service.ListDashboardsRequest`):
+            request (google.cloud.monitoring_dashboard_v1.types.ListDashboardsRequest):
                 The request object. The `ListDashboards` request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -416,15 +431,14 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListDashboardsPager:
-                The ``ListDashboards`` request.
+            google.cloud.monitoring_dashboard_v1.services.dashboards_service.pagers.ListDashboardsPager:
+                The ListDashboards request.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a dashboards_service.ListDashboardsRequest.
         # There's no risk of modifying the input as we've already verified
@@ -466,12 +480,12 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
         This method requires the ``monitoring.dashboards.get``
         permission on the specified dashboard. For more information, see
-        `Google Cloud IAM <https://cloud.google.com/iam>`__.
+        `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Args:
-            request (:class:`~.dashboards_service.GetDashboardRequest`):
+            request (google.cloud.monitoring_dashboard_v1.types.GetDashboardRequest):
                 The request object. The `GetDashboard` request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -479,7 +493,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.dashboard.Dashboard:
+            google.cloud.monitoring_dashboard_v1.types.Dashboard:
                 A Google Stackdriver dashboard.
                 Dashboards define the content and layout
                 of pages in the Stackdriver web
@@ -487,7 +501,6 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a dashboards_service.GetDashboardRequest.
         # There's no risk of modifying the input as we've already verified
@@ -523,12 +536,12 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
         This method requires the ``monitoring.dashboards.delete``
         permission on the specified dashboard. For more information, see
-        `Google Cloud IAM <https://cloud.google.com/iam>`__.
+        `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Args:
-            request (:class:`~.dashboards_service.DeleteDashboardRequest`):
+            request (google.cloud.monitoring_dashboard_v1.types.DeleteDashboardRequest):
                 The request object. The `DeleteDashboard` request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -536,7 +549,6 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a dashboards_service.DeleteDashboardRequest.
         # There's no risk of modifying the input as we've already verified
@@ -571,12 +583,12 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
         This method requires the ``monitoring.dashboards.update``
         permission on the specified dashboard. For more information, see
-        `Google Cloud IAM <https://cloud.google.com/iam>`__.
+        `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Args:
-            request (:class:`~.dashboards_service.UpdateDashboardRequest`):
+            request (google.cloud.monitoring_dashboard_v1.types.UpdateDashboardRequest):
                 The request object. The `UpdateDashboard` request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -584,7 +596,7 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.dashboard.Dashboard:
+            google.cloud.monitoring_dashboard_v1.types.Dashboard:
                 A Google Stackdriver dashboard.
                 Dashboards define the content and layout
                 of pages in the Stackdriver web
@@ -592,7 +604,6 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a dashboards_service.UpdateDashboardRequest.
         # There's no risk of modifying the input as we've already verified
