@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.monitoring_dashboard_v1.types import dashboard as gmd_dashboard
 
 
@@ -36,7 +33,6 @@ __protobuf__ = proto.module(
 
 class CreateDashboardRequest(proto.Message):
     r"""The ``CreateDashboard`` request.
-
     Attributes:
         parent (str):
             Required. The project on which to execute the request. The
@@ -48,19 +44,17 @@ class CreateDashboardRequest(proto.Message):
 
             The ``[PROJECT_ID_OR_NUMBER]`` must match the dashboard
             resource name.
-        dashboard (~.gmd_dashboard.Dashboard):
+        dashboard (google.cloud.monitoring_dashboard_v1.types.Dashboard):
             Required. The initial dashboard
             specification.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     dashboard = proto.Field(proto.MESSAGE, number=2, message=gmd_dashboard.Dashboard,)
 
 
 class ListDashboardsRequest(proto.Message):
     r"""The ``ListDashboards`` request.
-
     Attributes:
         parent (str):
             Required. The scope of the dashboards to list. The format
@@ -80,18 +74,15 @@ class ListDashboardsRequest(proto.Message):
             additional results from the previous method call.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
 
 
 class ListDashboardsResponse(proto.Message):
     r"""The ``ListDashboards`` request.
-
     Attributes:
-        dashboards (Sequence[~.gmd_dashboard.Dashboard]):
+        dashboards (Sequence[google.cloud.monitoring_dashboard_v1.types.Dashboard]):
             The list of requested dashboards.
         next_page_token (str):
             If there are more results than have been returned, then this
@@ -107,13 +98,11 @@ class ListDashboardsResponse(proto.Message):
     dashboards = proto.RepeatedField(
         proto.MESSAGE, number=1, message=gmd_dashboard.Dashboard,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetDashboardRequest(proto.Message):
     r"""The ``GetDashboard`` request.
-
     Attributes:
         name (str):
             Required. The resource name of the Dashboard. The format is
@@ -124,12 +113,11 @@ class GetDashboardRequest(proto.Message):
                (for custom dashboards).
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class DeleteDashboardRequest(proto.Message):
     r"""The ``DeleteDashboard`` request.
-
     Attributes:
         name (str):
             Required. The resource name of the Dashboard. The format is:
@@ -139,14 +127,13 @@ class DeleteDashboardRequest(proto.Message):
                 projects/[PROJECT_ID_OR_NUMBER]/dashboards/[DASHBOARD_ID]
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UpdateDashboardRequest(proto.Message):
     r"""The ``UpdateDashboard`` request.
-
     Attributes:
-        dashboard (~.gmd_dashboard.Dashboard):
+        dashboard (google.cloud.monitoring_dashboard_v1.types.Dashboard):
             Required. The dashboard that will replace the
             existing dashboard.
     """
