@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,12 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.monitoring_dashboard_v1.types import metrics
-from google.protobuf import duration_pb2 as duration  # type: ignore
+from google.protobuf import duration_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -29,11 +26,10 @@ __protobuf__ = proto.module(
 
 class XyChart(proto.Message):
     r"""A chart that displays data on a 2D (X and Y axes) plane.
-
     Attributes:
-        data_sets (Sequence[~.xychart.XyChart.DataSet]):
+        data_sets (Sequence[google.cloud.monitoring_dashboard_v1.types.XyChart.DataSet]):
             Required. The data displayed in this chart.
-        timeshift_duration (~.duration.Duration):
+        timeshift_duration (google.protobuf.duration_pb2.Duration):
             The duration used to display a comparison
             chart. A comparison chart simultaneously shows
             values from two similar-length time periods
@@ -41,35 +37,34 @@ class XyChart(proto.Message):
             The duration must be positive, and it can only
             be applied to charts with data sets of LINE plot
             type.
-        thresholds (Sequence[~.metrics.Threshold]):
+        thresholds (Sequence[google.cloud.monitoring_dashboard_v1.types.Threshold]):
             Threshold lines drawn horizontally across the
             chart.
-        x_axis (~.xychart.XyChart.Axis):
+        x_axis (google.cloud.monitoring_dashboard_v1.types.XyChart.Axis):
             The properties applied to the X axis.
-        y_axis (~.xychart.XyChart.Axis):
+        y_axis (google.cloud.monitoring_dashboard_v1.types.XyChart.Axis):
             The properties applied to the Y axis.
-        chart_options (~.xychart.ChartOptions):
+        chart_options (google.cloud.monitoring_dashboard_v1.types.ChartOptions):
             Display options for the chart.
     """
 
     class DataSet(proto.Message):
         r"""Groups a time series query definition with charting options.
-
         Attributes:
-            time_series_query (~.metrics.TimeSeriesQuery):
+            time_series_query (google.cloud.monitoring_dashboard_v1.types.TimeSeriesQuery):
                 Required. Fields for querying time series
                 data from the Stackdriver metrics API.
-            plot_type (~.xychart.XyChart.DataSet.PlotType):
+            plot_type (google.cloud.monitoring_dashboard_v1.types.XyChart.DataSet.PlotType):
                 How this data should be plotted on the chart.
             legend_template (str):
                 A template string for naming ``TimeSeries`` in the resulting
                 data set. This should be a string with interpolations of the
                 form ``${label_name}``, which will resolve to the label's
                 value.
-            min_alignment_period (~.duration.Duration):
+            min_alignment_period (google.protobuf.duration_pb2.Duration):
                 Optional. The lower bound on data point frequency for this
                 data set, implemented by specifying the minimum alignment
-                period to use in a time series query For example, if the
+                period to use in a time series query. For example, if the
                 data is published once every 10 minutes, the
                 ``min_alignment_period`` should be at least 10 minutes. It
                 would not make sense to fetch and align data at one minute
@@ -87,22 +82,18 @@ class XyChart(proto.Message):
         time_series_query = proto.Field(
             proto.MESSAGE, number=1, message=metrics.TimeSeriesQuery,
         )
-
         plot_type = proto.Field(proto.ENUM, number=2, enum="XyChart.DataSet.PlotType",)
-
-        legend_template = proto.Field(proto.STRING, number=3)
-
+        legend_template = proto.Field(proto.STRING, number=3,)
         min_alignment_period = proto.Field(
-            proto.MESSAGE, number=4, message=duration.Duration,
+            proto.MESSAGE, number=4, message=duration_pb2.Duration,
         )
 
     class Axis(proto.Message):
         r"""A chart axis.
-
         Attributes:
             label (str):
                 The label of the axis.
-            scale (~.xychart.XyChart.Axis.Scale):
+            scale (google.cloud.monitoring_dashboard_v1.types.XyChart.Axis.Scale):
                 The axis scale. By default, a linear scale is
                 used.
         """
@@ -113,32 +104,25 @@ class XyChart(proto.Message):
             LINEAR = 1
             LOG10 = 2
 
-        label = proto.Field(proto.STRING, number=1)
-
+        label = proto.Field(proto.STRING, number=1,)
         scale = proto.Field(proto.ENUM, number=2, enum="XyChart.Axis.Scale",)
 
     data_sets = proto.RepeatedField(proto.MESSAGE, number=1, message=DataSet,)
-
     timeshift_duration = proto.Field(
-        proto.MESSAGE, number=4, message=duration.Duration,
+        proto.MESSAGE, number=4, message=duration_pb2.Duration,
     )
-
     thresholds = proto.RepeatedField(
         proto.MESSAGE, number=5, message=metrics.Threshold,
     )
-
     x_axis = proto.Field(proto.MESSAGE, number=6, message=Axis,)
-
     y_axis = proto.Field(proto.MESSAGE, number=7, message=Axis,)
-
     chart_options = proto.Field(proto.MESSAGE, number=8, message="ChartOptions",)
 
 
 class ChartOptions(proto.Message):
     r"""Options to control visual rendering of a chart.
-
     Attributes:
-        mode (~.xychart.ChartOptions.Mode):
+        mode (google.cloud.monitoring_dashboard_v1.types.ChartOptions.Mode):
             The chart mode.
     """
 
